AllowList

Struct AllowList 

pub struct AllowList(/* private fields */);
A set of library names that are permitted to be imported.

Implementations

Source

impl AllowList

pub fn from_slice(libs: &[&[&str]]) -> Self

Create an allowlist from string library names.

Each entry is a slice of strings representing the library name components, e.g., &["rnrs", "base"] for (rnrs base).

pub fn add_lib(&mut self, lib: Vec<Symbol>)

Add a library to the allowlist.

pub fn contains(&self, lib_name: &[Symbol]) -> bool

Returns true if the given library name is in the allowlist.