pub struct Exception(pub Value);Expand description
A signal of some sort of erroneous condition.
Tuple Fields
0: ValueImplementations
Sourceimpl Exception
impl Exception
pub fn error(message: impl Display) -> Self
pub fn syntax(form: Syntax, subform: Option<Syntax>) -> Self
pub fn undefined(ident: Identifier) -> Self
pub fn type_error(expected: &str, provided: &str) -> Self
pub fn invalid_operator(provided: &str) -> Self
pub fn invalid_index(index: usize, len: usize) -> Self
pub fn invalid_range(range: Range<usize>, len: usize) -> Self
pub fn wrong_num_of_unicode_chars(expected: usize, provided: usize) -> Self
pub fn wrong_num_of_args(expected: usize, provided: usize) -> Self
pub fn wrong_num_of_var_args(expected: Range<usize>, provided: usize) -> Self
pub fn implementation_restriction(msg: impl Display) -> Self
Sourcepub fn conversion_error(expected: &str, provided: &str) -> Self
pub fn conversion_error(expected: &str, provided: &str) -> Self
For when we cannot convert a value into the requested type.
Example: Integer to a Complex
Sourcepub fn not_representable(value: &str, type: &str) -> Self
pub fn not_representable(value: &str, type: &str) -> Self
For when we cannot represent the value into the requested type.
Example: an u128 number as an u8
pub fn io_error(message: impl Display) -> Self
pub fn io_read_error(message: impl Display) -> Self
pub fn io_write_error(message: impl Display) -> Self
pub fn invalid_record_index(k: usize) -> Self
pub fn add_condition(self, condition: impl SchemeCompatible) -> Self
pub fn simple_conditions(&self) -> Result<Vec<Value>, Exception>
pub fn condition<T: SchemeCompatible>(&self) -> Result<Option<Gc<T>>, Exception>