pub struct List { /* private fields */ }Expand description
A proper list.
Conversion to this type guarantees that a type is a proper list and allows for fast retrieval of the length or any individual element of the list.
Performance
This is done by copying the list into a Vec, which can be a quite
expensive operation, so only use this if you need all elements of the list.
Implementations