ContBarrier

Struct ContBarrier 

pub struct ContBarrier<'a> { /* private fields */ }
A continuation barrier. Escape procedures created within a continuation barrier cannot be called within another barrier.

This structure also contains the dynamic state of the running program including winders, exception handlers, continuation marks, and parameters.

Implementations

Source

impl<'a> ContBarrier<'a>

pub fn new() -> Self

pub fn save(&self) -> SavedDynamicState

pub fn add_param(&mut self, key: impl Into<Symbol>, val: &'a mut impl Any)

pub fn get_param<'b>( &'b mut self, key: impl Into<Symbol>, ) -> Option<&'b mut dyn Any>

pub fn get_params_disjoint<'b, const N: usize>( &'b mut self, keys: [&Symbol; N], ) -> [Option<&'b mut dyn Any>; N]

pub fn iter_params<'b>( &'b mut self, ) -> impl Iterator<Item = (Symbol, &'b mut dyn Any)>

pub fn child_barrier<'b, 'c, const N: usize>( &'b mut self, params: [impl Into<Symbol>; N], ) -> ([Option<&'b mut dyn Any>; N], ContBarrier<'c>)
where 'b: 'c,

Constructs a child barrier from the current barrier, extracting an array of parameters that are not automatically passed onto the child.

pub fn current_exception_handler(&self) -> Option<Procedure>

pub fn current_input_port(&self) -> Port

pub fn current_output_port(&self) -> Port