pub struct Procedure(/* private fields */);Expand description
The runtime representation of a Procedure, which can be either a user function or a continuation. Contains a reference to all of the environmental variables used in the body, along with a function pointer to the body of the procedure.
Implementations
Sourceimpl Procedure
impl Procedure
Sourcepub fn new(
runtime: Runtime,
env: Vec<Value>,
func: impl Into<FuncPtr>,
num_required_args: usize,
variadic: bool,
) -> Self
pub fn new( runtime: Runtime, env: Vec<Value>, func: impl Into<FuncPtr>, num_required_args: usize, variadic: bool, ) -> Self
Creates a new procedure. func must be a BridgePtr or an
AsyncBridgePtr if async is enabled.
Sourcepub fn get_runtime(&self) -> Runtime
pub fn get_runtime(&self) -> Runtime
Get the runtime associated with the procedure
Sourcepub fn get_formals(&self) -> (usize, bool)
pub fn get_formals(&self) -> (usize, bool)
Return the number of required arguments and whether or not this function is variadic
Sourcepub fn get_debug_info(&self) -> Option<Arc<ProcDebugInfo>>
pub fn get_debug_info(&self) -> Option<Arc<ProcDebugInfo>>
Return the debug information associated with procedure, if it exists.
pub fn is_variable_transformer(&self) -> bool
Sourcepub fn is_continuation(&self) -> bool
pub fn is_continuation(&self) -> bool
Return whether or not the procedure is a continuation