pub type BridgePtr = fn(runtime: &Runtime, env: &[Value], args: &[Value], rest_args: &[Value], barrier: &mut ContBarrier<'_>, k: Value) -> Application;Expand description
A function pointer to a sync Rust bridge function.
pub type BridgePtr = fn(runtime: &Runtime, env: &[Value], args: &[Value], rest_args: &[Value], barrier: &mut ContBarrier<'_>, k: Value) -> Application;A function pointer to a sync Rust bridge function.