pub struct Record(/* private fields */);Expand description
A Scheme record type. Effectively a tuple of a fixed size array and some type information.
Implementations
Sourceimpl Record
impl Record
pub fn rtd(&self) -> Arc<RecordTypeDescriptor>
Sourcepub fn from_rust_type<T: SchemeCompatible>(t: T) -> Self
pub fn from_rust_type<T: SchemeCompatible>(t: T) -> Self
Convert any Rust type that implements SchemeCompatible into an opaque record.
Sourcepub fn cast<T: SchemeCompatible>(&self) -> Option<Gc<T>>
pub fn cast<T: SchemeCompatible>(&self) -> Option<Gc<T>>
Attempt to convert the record into a Rust type that implements SchemeCompatible.
Sourcepub fn get_parent_field(
&self,
rtd: &Arc<RecordTypeDescriptor>,
k: usize,
) -> Result<Value, Exception>
pub fn get_parent_field( &self, rtd: &Arc<RecordTypeDescriptor>, k: usize, ) -> Result<Value, Exception>
Get the kth field of a parent Record
Sourcepub fn set_field(&self, k: usize, new_value: Value) -> Result<(), Exception>
pub fn set_field(&self, k: usize, new_value: Value) -> Result<(), Exception>
Set the kth field of the Record
Sourcepub fn set_parent_field(
&self,
rtd: &Arc<RecordTypeDescriptor>,
k: usize,
new_value: Value,
) -> Result<(), Exception>
pub fn set_parent_field( &self, rtd: &Arc<RecordTypeDescriptor>, k: usize, new_value: Value, ) -> Result<(), Exception>
Set the kth field of a parent Record