String builtins and data types.
Although we would like to, the R6RS standard of Rust precludes us from using the standard library String type by mandating O(1) lookups of characters from indices. This means that Scheme strings are vectors of unicode code points rather that UTF-8 strings.
Structs
- Wide
String - A string that is a vector of characters, rather than a vector bytes encoding a utf-8 string. This is because R6RS mandates O(1) lookups of character indices.