UnpackedValue

Enum UnpackedValue 

#[non_exhaustive]
pub enum UnpackedValue {
Show 17 variants Undefined, Null, Boolean(bool), Character(char), Number(Number), String(WideString), Symbol(Symbol), Vector(Vector), ByteVector(ByteVector), Syntax(Gc<Syntax>), Procedure(Procedure), Record(Record), RecordTypeDescriptor(Arc<RecordTypeDescriptor>), Pair(Pair), Port(Port), HashTable(HashTable), Cell(Cell),
}
The external, unpacked, enumeration representation of a scheme value.

Values that are not potentially cyclical, such as syntax objects and byte vectors use Arcs as they are much less expensive than Gc types.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Undefined



Null



Boolean(bool)



Character(char)



Number(Number)



String(WideString)



Symbol(Symbol)



Vector(Vector)



ByteVector(ByteVector)



Syntax(Gc<Syntax>)



Procedure(Procedure)



Record(Record)



RecordTypeDescriptor(Arc<RecordTypeDescriptor>)



Pair(Pair)



Port(Port)



HashTable(HashTable)



Cell(Cell)

Implementations

Source

impl UnpackedValue

pub fn into_value(self) -> Value

pub fn eq(&self, rhs: &Self) -> bool

pub fn eqv(&self, rhs: &Self) -> bool

pub fn type_name(&self) -> &'static str

pub fn type_of(&self) -> ValueType