pub struct TopLevelEnvironment(/* private fields */);Expand description
A top level environment such as a library, program, or REPL.
Implementations
Sourceimpl TopLevelEnvironment
impl TopLevelEnvironment
pub fn new_repl(rt: &Runtime) -> Self
pub fn from_spec( rt: &Runtime, spec: LibrarySpec, path: PathBuf, ) -> Result<Self, Exception>
Sourcepub fn eval(
&self,
import_policy: impl Into<ImportPolicy>,
code: &str,
) -> Result<Vec<Value>, Exception>
pub fn eval( &self, import_policy: impl Into<ImportPolicy>, code: &str, ) -> Result<Vec<Value>, Exception>
Evaluate the scheme expression in the provided environment and return
the values. The import_policy controls which libraries may be imported;
use ImportPolicy::Allow to permit all imports, or provide an allowlist
of specific libraries.
pub fn eval_sexpr( &self, import_policy: impl Into<ImportPolicy>, sexpr: Syntax, ) -> Result<Vec<Value>, Exception>
pub fn import(&self, import_set: ImportSet) -> Result<(), Exception>
pub fn is_repl(&self) -> bool
pub fn def_var(&self, binding: Binding, name: Symbol, value: Value) -> Global
pub fn lookup_var(&self, binding: Binding) -> Result<Option<Global>, Exception>
pub fn lookup_var_inner( &self, binding: Binding, ) -> Result<Option<Global>, Exception>
pub fn def_keyword(&self, binding: Binding, transformer: Procedure)
pub fn lookup_keyword( &self, binding: Binding, ) -> Result<Option<Procedure>, Exception>
pub fn lookup_keyword_inner( &self, binding: Binding, ) -> Result<Option<Procedure>, Exception>
pub fn lookup_primitive(&self, binding: Binding) -> Option<Primitive>