Scheme-rs core runtime.
The Runtime struct initializes and stores the core runtime for
scheme-rs. It contains a registry of libraries and the memory associated
with the JIT compiled Procedures.
Structs
- Runtime
- Scheme-rs core runtime