pub struct Value(/* private fields */);Expand description
A Scheme value. See the module documentation for more information.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn new(v: UnpackedValue) -> Self
pub fn new(v: UnpackedValue) -> Self
Create a new Value from an UnpackedValue.
This is generally discouraged as it’s cumbersome; try using From
instead.
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
Sourcepub unsafe fn from_raw_inc_rc(raw: *const ()) -> Self
pub unsafe fn from_raw_inc_rc(raw: *const ()) -> Self
Sourcepub fn into_raw(val: Self) -> *const ()
pub fn into_raw(val: Self) -> *const ()
Creates a raw u64 from a Value. Does not decrement the reference count. Calling this function without turning the raw value into a Value via from_raw is equivalent to calling mem::forget on the value.
Sourcepub fn as_raw(this: &Self) -> *const ()
pub fn as_raw(this: &Self) -> *const ()
Creates a raw u64 from the Value. Does not decrement the reference count.
pub fn undefined() -> Self
pub fn null() -> Self
Sourcepub fn datum_from_syntax(syntax: &Syntax) -> Self
pub fn datum_from_syntax(syntax: &Syntax) -> Self
Convert a Syntax into its corresponding datum representation.
pub fn type_of(&self) -> ValueType
pub fn type_name(&self) -> &'static str
Sourcepub fn cast_to_scheme_type<T>(&self) -> Option<T>
pub fn cast_to_scheme_type<T>(&self) -> Option<T>
Attempt to cast the value into a Scheme primitive type.
Sourcepub fn try_to_scheme_type<T>(&self) -> Result<T, Exception>
pub fn try_to_scheme_type<T>(&self) -> Result<T, Exception>
Attempt to cast the value into a Scheme primitive type and return a descriptive error on failure.
Sourcepub fn cast_to_rust_type<T: SchemeCompatible>(&self) -> Option<Gc<T>>
pub fn cast_to_rust_type<T: SchemeCompatible>(&self) -> Option<Gc<T>>
Attempt to cast the value into a Rust type that implements
SchemeCompatible.
Sourcepub fn try_to_rust_type<T: SchemeCompatible>(&self) -> Result<Gc<T>, Exception>
pub fn try_to_rust_type<T: SchemeCompatible>(&self) -> Result<Gc<T>, Exception>
Attempt to cast the value into a Rust type and return a descriptive error on failure.
Sourcepub fn from_rust_type<T: SchemeCompatible>(t: T) -> Self
pub fn from_rust_type<T: SchemeCompatible>(t: T) -> Self
Automatically convert a SchemeCompatible type to a Record and then
into a Value.
Sourcepub fn unpack(self) -> UnpackedValue
pub fn unpack(self) -> UnpackedValue
Unpack the value into an enum representation.
pub fn unpacked_ref(&self) -> UnpackedValueRef<'_>
Sourcepub fn equal(&self, rhs: &Self) -> bool
pub fn equal(&self, rhs: &Self) -> bool
The equal? predicate as defined by the R6RS specification.
Sourcepub fn eq_hash<H: Hasher>(&self, state: &mut H)
pub fn eq_hash<H: Hasher>(&self, state: &mut H)
Performs a hash suitable for use with eq? as an equivalance function