Value

Struct Value 

pub struct Value(/* private fields */);
A Scheme value. See the module documentation for more information.

Implementations

Source

impl Value

pub fn new(v: UnpackedValue) -> Self

Create a new Value from an UnpackedValue.

This is generally discouraged as it’s cumbersome; try using From instead.

pub fn is_true(&self) -> bool

#f is false, everything else is true

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub unsafe fn from_raw(raw: *const ()) -> Self

Creates a new Value from a raw u64.

Safety

Calling this function is undefined behavior if the raw u64 was not obtained via into_raw

pub unsafe fn from_raw_inc_rc(raw: *const ()) -> Self

Creates a new Value from a raw u64, incrementing the reference count.

Safety

Calling this function is undefined behavior if the raw u64 was not obtained via into_raw

pub fn into_raw(val: Self) -> *const ()

Creates a raw u64 from a Value. Does not decrement the reference count. Calling this function without turning the raw value into a Value via from_raw is equivalent to calling mem::forget on the value.

pub fn as_raw(this: &Self) -> *const ()

Creates a raw u64 from the Value. Does not decrement the reference count.

pub fn undefined() -> Self

pub fn null() -> Self

pub fn datum_from_syntax(syntax: &Syntax) -> Self

Convert a Syntax into its corresponding datum representation.

pub fn type_of(&self) -> ValueType

pub fn type_name(&self) -> &'static str

pub fn cast_to_scheme_type<T>(&self) -> Option<T>
where for<'a> &'a Self: Into<Option<T>>,

Attempt to cast the value into a Scheme primitive type.

pub fn try_to_scheme_type<T>(&self) -> Result<T, Exception>
where T: for<'a> TryFrom<&'a Self, Error = Exception>,

Attempt to cast the value into a Scheme primitive type and return a descriptive error on failure.

pub fn cast_to_rust_type<T: SchemeCompatible>(&self) -> Option<Gc<T>>

Attempt to cast the value into a Rust type that implements SchemeCompatible.

pub fn try_to_rust_type<T: SchemeCompatible>(&self) -> Result<Gc<T>, Exception>

Attempt to cast the value into a Rust type and return a descriptive error on failure.

pub fn from_rust_type<T: SchemeCompatible>(t: T) -> Self

Automatically convert a SchemeCompatible type to a Record and then into a Value.

pub fn unpack(self) -> UnpackedValue

Unpack the value into an enum representation.

pub fn unpacked_ref(&self) -> UnpackedValueRef<'_>

pub fn eq(&self, rhs: &Self) -> bool

The eq? predicate as defined by the R6RS specification.

pub fn eqv(&self, rhs: &Self) -> bool

The eqv? predicate as defined by the R6RS specification.

pub fn equal(&self, rhs: &Self) -> bool

The equal? predicate as defined by the R6RS specification.

pub fn eq_hash<H: Hasher>(&self, state: &mut H)

Performs a hash suitable for use with eq? as an equivalance function

pub fn eqv_hash<H: Hasher>(&self, state: &mut H)

Performs a hash suitable for use with eqv? as an equivalance function

pub fn equal_hash<H: Hasher>( &self, recursive: &mut IndexSet<Value>, state: &mut H, )

Performs a hash suitable for use with equal? as an equivalance function